==> haskell-trifecta-1.6.2.1-31-i686.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.6.2.1
id: trifecta-1.6.2.1-AmrK23tqKy5Hy8lmwHwsWK
key: trifecta-1.6.2.1-AmrK23tqKy5Hy8lmwHwsWK
license: BSD3
copyright: Copyright (C) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
abi: e14cde0eef69abb8548fe320c0597939
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/trifecta-1.6.2.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/trifecta-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/trifecta-1.6.2.1
hs-libraries: HStrifecta-1.6.2.1-AmrK23tqKy5Hy8lmwHwsWK
depends:
    ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp
    ansi-wl-pprint-0.6.7.3-7jqnIfTUHr2Bkg0VIWs8Q5 array-0.5.1.1
    base-4.9.1.0 blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    charset-0.3.7.1-ExxkLwSUKUPEceMD96Skef
    comonad-5.0.1-57iqRHH7ifDe0jWuqpsGW containers-0.5.7.1
    deepseq-1.4.2.0 fingertree-0.1.1.0-Aiaf912zjZGHvH3XyjxrYA
    ghc-prim-0.5.0.0 hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    lens-4.15.3-60anFPcl0sa4AbScjQzShN mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    parsers-0.12.5-AXzq17gNTfCKs6hv5mWVL8
    profunctors-5.2-8AU42QqEa6oClTRTu9iu4K
    reducers-3.12.1-Ht4a7jugA5A5jE9S7HTqYz
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-1.6.2.1-33-i686.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 1.6.2.1
id: trifecta-1.6.2.1-FU2w7EDlQ3HDDecWF8RTrU
key: trifecta-1.6.2.1-FU2w7EDlQ3HDDecWF8RTrU
license: BSD3
copyright: Copyright (C) 2010-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
author: Edward A. Kmett
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Util.Array Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
abi: 3713bc6b1ab35681ae1cc8a6c1333f29
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/trifecta-1.6.2.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/trifecta-1.6.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/trifecta-1.6.2.1
hs-libraries: HStrifecta-1.6.2.1-FU2w7EDlQ3HDDecWF8RTrU
depends:
    ansi-terminal-0.6.3.1-59sjf9WqHYuFAo9gQw9Bhp
    ansi-wl-pprint-0.6.7.3-7jqnIfTUHr2Bkg0VIWs8Q5 array-0.5.1.1
    base-4.9.1.0 blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    blaze-html-0.8.1.3-EHw0sCLFL6JKZx2lFkE5O8
    blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0 bytestring-0.10.8.1
    charset-0.3.7.1-ExxkLwSUKUPEceMD96Skef
    comonad-5.0.1-57iqRHH7ifDe0jWuqpsGW containers-0.5.7.1
    deepseq-1.4.2.0 fingertree-0.1.1.0-Aiaf912zjZGHvH3XyjxrYA
    ghc-prim-0.5.0.0 hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    lens-4.15.3-6ghM1rB2SVx7pTJuxB037l mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    parsers-0.12.5-AXzq17gNTfCKs6hv5mWVL8
    profunctors-5.2.1-5x71Wug1TnuAdpWqS2CUNd
    reducers-3.12.1-oQwGPg4IdHSyMXJrkqbP
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
